package WebGUI::i18n::Dutch::Asset;
use utf8;
our $I18N = {
  '%s is not a valid depth' => {
    'lastUpdated' => '1224075526',
    'message' => '%s is geen geldig niveau.'
  },
  104 => {
    'lastUpdated' => '1146577899',
    'message' => 'URL'
  },
  '104 description' => {
    'lastUpdated' => '1152860296',
    'message' => 'Vul hier een unieke URL voor de asset in. Indien deze niet wordt ingevuld dan wordt deze samengesteld door de bovenliggende URL en de menu titel.'
  },
  105 => {
    'lastUpdated' => '1146578562',
    'message' => 'Weergave'
  },
  107 => {
    'lastUpdated' => '1146578556',
    'message' => 'Beveiliging'
  },
  1073 => {
    'lastUpdated' => '1146578572',
    'message' => 'Stijl sjabloon'
  },
  1079 => {
    'lastUpdated' => '1166435446',
    'message' => 'Print sjabloon'
  },
  108 => {
    'lastUpdated' => '1146578737',
    'message' => 'Eigenaar'
  },
  '108 description' => {
    'lastUpdated' => '1181289125',
    'message' => 'De eigenaar van de Asset is diegene die de asset heeft aangemaakt. Deze gebruiker heeft alle rechten voor het bekijken en wijzigen van de Asset. Standaard is de eigenaar van de Asset de eigenaar van de bovenliggende Asset. De eigenaar van de Asset kan alleen worden gewijzigd door een Administrator.'
  },
  1082 => {
    'lastUpdated' => '1146578806',
    'message' => 'Klembord'
  },
  1083 => {
    'lastUpdated' => '1146578821',
    'message' => 'Inhoud toevoegen'
  },
  11 => {
    'lastUpdated' => '1146578845',
    'message' => 'Leeg prullenbak'
  },
  174 => {
    'lastUpdated' => '1146578880',
    'message' => 'Titel laten zien?'
  },
  411 => {
    'lastUpdated' => '1146578916',
    'message' => 'Menu titel'
  },
  '411 description' => {
    'lastUpdated' => '1152860351',
    'message' => 'De omschrijving voor het navigatiemenu. Indien deze niet wordt ingevuld dan wordt de titel overgenomen.'
  },
  412 => {
    'lastUpdated' => '1146579024',
    'message' => 'Samenvatting'
  },
  '412 description' => {
    'lastUpdated' => '1152860357',
    'message' => 'Een korte omschrijving van de asset.'
  },
  43 => {
    'lastUpdated' => '1250240725',
    'message' => 'Weet u zeker dat u de gehele inhoud en alles wat hieronder zit wilt verwijderen? Deze verandering wordt niet in een versie tag gezet en zal direct uitgevoerd worden.'
  },
  486 => {
    'lastUpdated' => '1146580011',
    'message' => 'Type'
  },
  487 => {
    'lastUpdated' => '1146579997',
    'message' => 'Mogelijke waarden'
  },
  85 => {
    'lastUpdated' => '1146580019',
    'message' => 'Omschrijving'
  },
  871 => {
    'lastUpdated' => '1146580041',
    'message' => 'Wie kan wijzigen?'
  },
  '871 description' => {
    'lastUpdated' => '1189121367',
    'message' => 'Selecteer welke groep het object kan wijzigen. Deze groep kan automatisch de asset zien. Wanneer dit niet wordt ingesteld, wordt dit automatisch de groep die het bovenliggende object kan wijzigen.'
  },
  872 => {
    'lastUpdated' => '1146580246',
    'message' => 'Wie mag bekijken?'
  },
  '872 description' => {
    'lastUpdated' => '1207818861',
    'message' => 'Selecteer welke groep dit object mag zien. Om zowel bezoekers als geregistreerde gebruikers het object te laten zien kan \'iedereen\' (everyone) gekozen worden. Als dit niet wordt gewijzigd, dan wordt dit standaard ingesteld op de groep die het bovenliggende object mag zien.'
  },
  886 => {
    'lastUpdated' => '1146580347',
    'message' => 'Verbergen in navigatie?'
  },
  '886 description' => {
    'lastUpdated' => '1152860378',
    'message' => 'Kies of u de asset wilt weergeven in navigatiemenu&#39;s.'
  },
  895 => {
    'lastUpdated' => '1146580417',
    'message' => 'Cache Timeout'
  },
  896 => {
    'lastUpdated' => '1146580430',
    'message' => 'Cache timeout (bezoekers)'
  },
  940 => {
    'lastUpdated' => '1146580446',
    'message' => 'In een nieuw venster openen?'
  },
  '940 description' => {
    'lastUpdated' => '1207819061',
    'message' => 'Klik op &quot;Ja&quot; als u de asset in een nieuw venster wilt openen. Hou er dan wel rekening mee dat het mogelijk is dat dit niet werkt in sommige navigatiemenu\'s, als de gebruiker het gebruik van Javascript uit heeft staan of als de gebruiker een popup blocker ge&iuml;nstalleerd heeft. Gebruik deze functie zorgvuldig.'
  },
  949 => {
    'lastUpdated' => '1146580623',
    'message' => 'Beheer klembord'
  },
  950 => {
    'lastUpdated' => '1146580631',
    'message' => 'Leeg klembord'
  },
  951 => {
    'lastUpdated' => '1146580646',
    'message' => 'Weet u zeker dat u het klembord wilt verwijderen?'
  },
  954 => {
    'lastUpdated' => '1146580710',
    'message' => 'Beheer systeem klembord'
  },
  959 => {
    'lastUpdated' => '1146580705',
    'message' => 'Leeg systeem klembord'
  },
  964 => {
    'lastUpdated' => '1146580698',
    'message' => 'Beheer systeem prullenbak'
  },
  965 => {
    'lastUpdated' => '1146580725',
    'message' => 'Systeem prullenbak'
  },
  966 => {
    'lastUpdated' => '1146580734',
    'message' => 'Systeem klembord'
  },
  99 => {
    'lastUpdated' => '1146580741',
    'message' => 'Titel'
  },
  '99 description' => {
    'lastUpdated' => '1207818077',
    'message' => 'De titel van het object. Omschrijf het object met zorg, maar houd het kort. Indien de titel niet wordt ingevuld dan wordt hier &quot;Untitled&quot; ingevuld. Er kunnen geen macro\'s in de titel worden gebruikt en er kan geen HTML of javascript in gezet worden.   Opmerking: Het is van belang om altijd de titel op te geven. Zelfs als het template van het asset de titel niet weergeeft. Op verschillende plaatsen in de site, zoals de Verkenner (Asset Manager), het klembord en de prullenbak wordt de titel gebruikt om het object te onderscheiden. '
  },
  'Add new field' => {
    'lastUpdated' => '1146580856',
    'message' => 'Voeg metadata toe'
  },
  'Add new field description' => {
    'lastUpdated' => '1246969008',
    'message' => 'Open een formulier waar nieuwe velden voor metadata aan dit asset kunnen worden toegevoegd.'
  },
  'Allowed Classes' => {
    'lastUpdated' => '1298566436',
    'message' => 'Toegestane klassen'
  },
  'Allowed Classes hoverHelp' => {
    'lastUpdated' => '1298566455',
    'message' => 'Welke assets gebruiken deze metadata?'
  },
  'Any Class' => {
    'lastUpdated' => '1259235175',
    'message' => 'Elke klasse'
  },
  'Attempting to commit changes' => {
    'lastUpdated' => '1258536057',
    'message' => 'Veranderingen aan het proberen door te voeren.'
  },
  'Class Icon' => {
    'lastUpdated' => '1222350784',
    'message' => 'Klasse Icoon'
  },
  'Class Icon help' => {
    'lastUpdated' => '1166187449',
    'message' => 'Iedere asset heeft een icoon om aan te geven wat voor een asset het is. Door te klikken op het icoontje verschijnt er een drop-down menu met opties om de asset te wijzigen. '
  },
  'Clearing asset tables' => {
    'lastUpdated' => '1246968412',
    'message' => 'Asset tabellen opschonen'
  },
  'Clearing cache' => {
    'lastUpdated' => '1246968429',
    'message' => 'Cache opschonen'
  },
  'Clearing search index' => {
    'lastUpdated' => '1246976620',
    'message' => 'Zoekresultaten opruimen'
  },
  'Copy' => {
    'lastUpdated' => '1222875572',
    'message' => 'Kopi&euml;ren'
  },
  'Copy Assets' => {
    'lastUpdated' => '1275486748',
    'message' => 'Kopi&euml;er assets'
  },
  'Data Type description' => {
    'lastUpdated' => '1146580963',
    'message' => 'Selecteer het soort form element voor het veld.'
  },
  'Delete Assets' => {
    'lastUpdated' => '1251878045',
    'message' => 'Verwijder assets'
  },
  'Delete Metadata field' => {
    'lastUpdated' => '1146580993',
    'message' => 'Verwijder Metadata veld'
  },
  'Deleting exported files' => {
    'lastUpdated' => '1246976662',
    'message' => 'Geëxporteerde bestanden verwijderen'
  },
  'Deleting keywords' => {
    'lastUpdated' => '1246969121',
    'message' => 'Trefwoorden verwijderen'
  },
  'Depth' => {
    'lastUpdated' => '1146581003',
    'message' => 'Diepte'
  },
  'Depth description' => {
    'lastUpdated' => '1146581102',
    'message' => 'Stel de diepte van de te exporteren pagina\'s in. Gebruik als diepte "0" om alleen de huidige pagina te exporteren.'
  },
  'Edit Metadata' => {
    'lastUpdated' => '1146581111',
    'message' => 'Wijzig Metadata veld'
  },
  'Error getting asset with assetId %s' => {
    'lastUpdated' => '1246969162',
    'message' => 'Fout bij het ophalen van asset met assetId %s.'
  },
  'Error: Cannot instantiate template' => {
    'lastUpdated' => '1222875645',
    'message' => 'Fout: Kan sjabloon niet vinden'
  },
  'Export Page' => {
    'lastUpdated' => '1146581157',
    'message' => 'Exporteer pagina'
  },
  'Export Related Assets' => {
    'lastUpdated' => '1302247730',
    'message' => 'Exporteer gerelateerde assets'
  },
  'Export Related Assets description' => {
    'lastUpdated' => '1302247758',
    'message' => 'Gerelateerde assets meenemen in export?'
  },
  'Export as user' => {
    'lastUpdated' => '1146581167',
    'message' => 'Exporteer als gebruiker'
  },
  'Export as user description' => {
    'lastUpdated' => '1146581243',
    'message' => 'Exporteer als deze gebruiker, standaard wordt hiervoor "Bezoeker" gebruikt.'
  },
  'Export site root URL' => {
    'lastUpdated' => '1222875665',
    'message' => 'Exporteer de URL van de site root'
  },
  'Export site root URL description' => {
    'lastUpdated' => '1227567912',
    'message' => 'Een URL voor Macro Widgets'
  },
  'Extras URL' => {
    'lastUpdated' => '1146581256',
    'message' => 'Extras URL'
  },
  'Extras URL description' => {
    'lastUpdated' => '1146581737',
    'message' => 'Stel de Extras URL in. Standaard staat deze ingesteld op de extrasURL in het WebGUI configuratiebestand. '
  },
  'Field Id' => {
    'lastUpdated' => '1146581330',
    'message' => 'Veld Id'
  },
  'Field Name description' => {
    'lastUpdated' => '1213624722',
    'message' => 'De naam van het metadata veld. Het veld moet uniek zijn en bij voorkeur alleen letters (a-z), nummers (0-9) en underscores (_) bevatten. Verder mag het niet meer dan 100 karakters lang zijn.'
  },
  'Field name' => {
    'lastUpdated' => '1146581422',
    'message' => 'Veldnaam'
  },
  'Metadata' => {
    'lastUpdated' => '1146581429',
    'message' => 'Metadata'
  },
  'Metadata Description description' => {
    'lastUpdated' => '1146581529',
    'message' => 'Een optionele omschrijving voor het metadata veld. Deze wordt weergegeven als mouseover-event bij de tab "Eigenschappen" van de asset. '
  },
  'More' => {
    'lastUpdated' => '1227567875',
    'message' => 'Meer'
  },
  'Page Export' => {
    'lastUpdated' => '1146581568',
    'message' => 'Pagina, Exporteren'
  },
  'Page Export Status' => {
    'lastUpdated' => '1207915501',
    'message' => 'Pagina Export Status'
  },
  'Paste' => {
    'lastUpdated' => '1246968450',
    'message' => 'Plakken'
  },
  'Paste Assets' => {
    'lastUpdated' => '1246969176',
    'message' => 'Plak assets'
  },
  'Possible Values description' => {
    'lastUpdated' => '1248100513',
    'message' => 'Dit veld wordt alleen gebruikt voor Radio buttons en Select lists. Vul per regel de gewenste waarden in. 

Als er een ander label voor een waarde gebruikt moet worden, moeten de mogelijke waarden als volgt ingevoerd worden:

label1|waarde1
label2|waarde2
label3|waarde3
...

Hierbij worden het label en de bijbehorende waarde door het | teken gescheiden. Plaats geen spaties voor of na de |. Let erop ook op dat je regels met verschillende labels kan mixen met regels met hetzelfde label. Als er een selectBox gemaakt wordt, wordt er automatisch een Selecteer mogelijkheid toegevoegd aan de lijst met opties.'
  },
  'Processing form data' => {
    'lastUpdated' => '1258536070',
    'message' => 'Formulier data verwerken'
  },
  'Purging %s' => {
    'lastUpdated' => '1248099933',
    'message' => '%s aan het verwijderen'
  },
  'Purging shortcuts' => {
    'lastUpdated' => '1248099947',
    'message' => 'Snelkoppelingen verwijderen'
  },
  'Select' => {
    'lastUpdated' => '1146581864',
    'message' => 'Selecteer...'
  },
  'Set Rank' => {
    'lastUpdated' => '1246969206',
    'message' => 'Stel rang in'
  },
  'Trying to delete system page %s.  Aborting' => {
    'lastUpdated' => '1251878064',
    'message' => 'Er wordt geprobeerd de systeempagina %s te verwijderen. Dit wordt afgebroken'
  },
  'Undefined child' => {
    'lastUpdated' => '1246976717',
    'message' => 'Er wordt geprobeerd de systeem pagina %s te verwijderen. Verwijderen wordt gestopt.'
  },
  'Uploads URL' => {
    'lastUpdated' => '1146581876',
    'message' => 'Uploads URL'
  },
  'Uploads URL description' => {
    'lastUpdated' => '1146581905',
    'message' => 'Stel de Uploads URL in. Standaard verwijst deze naar de uploadsURL in het configuratiebestand.'
  },
  'You cannot edit the asset %s, skipping' => {
    'lastUpdated' => '1246969251',
    'message' => 'Het asset %s kan niet bewerkt worden, deze stap wordt overgeslagen.'
  },
  'add the missing page' => {
    'lastUpdated' => '1149234541',
    'message' => 'De pagina aanmaken'
  },
  'ago' => {
    'lastUpdated' => '1146581918',
    'message' => 'geleden'
  },
  'apply' => {
    'lastUpdated' => '1224075536',
    'message' => 'Toepassen'
  },
  'asset' => {
    'lastUpdated' => '1146668453',
    'message' => 'Asset'
  },
  'asset id' => {
    'lastUpdated' => '1146829926',
    'message' => 'Asset ID'
  },
  'asset id description' => {
    'lastUpdated' => '1146830038',
    'message' => 'Dit is het unieke ID waarmee de Asset gevonden kan worden. Standaard gebruikers zullen dit ID niet snel gebruiken maar experts kunnen dit ID gebruiken voor bijvoorbeeld een SQL Report of in een Macro. Het Asset ID kan niet gewijzigd worden. '
  },
  'asset list title' => {
    'lastUpdated' => '1146830076',
    'message' => 'Asset, Lijst van beschikbare'
  },
  'asset template asset var title' => {
    'lastUpdated' => '1170685518',
    'message' => 'Asset Sjabloon Asset Variabelen'
  },
  'asset template title' => {
    'lastUpdated' => '1146830214',
    'message' => 'Asset Template variabelen'
  },
  'assetHistory' => {
    'lastUpdated' => '1238281324',
    'message' => 'Asset historie'
  },
  'assetId' => {
    'lastUpdated' => '1257328168',
    'message' => 'De unieke id van dit Asset, in base64 gecodeerd.'
  },
  'assetIdHex' => {
    'lastUpdated' => '1257328187',
    'message' => 'De unieke id van dit Asset, in hexadecimaal formaat.'
  },
  'assetSize' => {
    'lastUpdated' => '1170685552',
    'message' => 'De grootte van het asset in bytes. Dit is de som van alle databasevelden en de attachments.'
  },
  'assets' => {
    'lastUpdated' => '1146830228',
    'message' => 'Assets'
  },
  'bad user privileges' => {
    'lastUpdated' => '1146830248',
    'message' => 'De gebruiker heeft geen rechten voor het bekijken van deze pagina.'
  },
  'change' => {
    'lastUpdated' => '1146830320',
    'message' => 'Recursief veranderen?'
  },
  'change url' => {
    'lastUpdated' => '1146830333',
    'message' => 'Wijzig URL'
  },
  'change url help' => {
    'lastUpdated' => '1148988883',
    'message' => 'Laat het scherm zien voor het wijzigen van de URL van deze asset.'
  },
  'clear package flag' => {
    'lastUpdated' => '1275486775',
    'message' => 'Pakket status opschonen'
  },
  'committed versions' => {
    'lastUpdated' => '1148988911',
    'message' => 'Goedgekeurde versies'
  },
  'confirm change' => {
    'lastUpdated' => '1146830344',
    'message' => 'Weet u het zeker?'
  },
  'confirm change url message' => {
    'lastUpdated' => '1166203930',
    'message' => 'Indien u "Ja" selecteert wijzigt u de URL definitief. Dit betekent dat alle oude revisies van de Asset verwijderd zullen worden. '
  },
  'content profiling' => {
    'lastUpdated' => '1146830566',
    'message' => 'Metadata beheer '
  },
  'controls' => {
    'lastUpdated' => '1166203953',
    'message' => 'Met deze iconen en url\'s kunt u een asset wijzigen, knippen, kopiëren, verwijderen en verplaatsen.'
  },
  'copy' => {
    'lastUpdated' => '1222875690',
    'message' => 'copi&euml;ren'
  },
  'could not create' => {
    'lastUpdated' => '1166187502',
    'message' => 'Kan %s: %s niet aanmaken.'
  },
  'could not create path' => {
    'lastUpdated' => '1166204011',
    'message' => 'Kan %-s niet aanmaken omdat %-s <BR>Dit komt waarschijnlijk doordat er een pagina is met dezelfde naam als de map die u wilt aanmaken '
  },
  'could not open path' => {
    'lastUpdated' => '1146831142',
    'message' => 'Kan %-s niet openen omdat %-s'
  },
  'could not rmdir' => {
    'lastUpdated' => '1166187519',
    'message' => 'Kan de map %s: %s niet verwijderen.'
  },
  'could not symlink' => {
    'lastUpdated' => '1166187549',
    'message' => 'Kan geen symbolische link aanmaken naar %s to %s: %s.'
  },
  'could not unlink' => {
    'lastUpdated' => '1166187568',
    'message' => 'Kan de link %s: %s niet verwijderen.'
  },
  'create package' => {
    'lastUpdated' => '1166436967',
    'message' => 'Als pakket activeren?'
  },
  'create shortcut' => {
    'lastUpdated' => '1146831211',
    'message' => 'Maak snelkoppeling'
  },
  'current url' => {
    'lastUpdated' => '1148988927',
    'message' => 'Huidige URL.'
  },
  'cut' => {
    'lastUpdated' => '1146831220',
    'message' => 'Knippen'
  },
  'default value' => {
    'lastUpdated' => '1190028085',
    'message' => 'Standaard waarde(n)'
  },
  'default value description' => {
    'lastUpdated' => '1213624836',
    'message' => 'De standaard waarde voor dit veld. Als er meerdere standaard waarden zijn, zoals bij een checkboxlijst, geef er dan een per regel. De maximaal toegestane hoeveelheid data is 255 karakters.'
  },
  'delete' => {
    'lastUpdated' => '1146831230',
    'message' => 'Verwijderen'
  },
  'deleteConfirm' => {
    'lastUpdated' => '1146831249',
    'message' => 'Weet u zeker dat u dit Metadata veld wilt verwijderen?'
  },
  'demote' => {
    'lastUpdated' => '1146831301',
    'message' => 'Degradeer'
  },
  'demote %s' => {
    'lastUpdated' => '1248099701',
    'message' => 'degradeer %s'
  },
  'demote help' => {
    'lastUpdated' => '1166204029',
    'message' => 'Verplaats deze asset één plaats omlaag.  '
  },
  'directory index' => {
    'lastUpdated' => '1146831438',
    'message' => 'Mappenstructuur'
  },
  'directory index description' => {
    'lastUpdated' => '1166204038',
    'message' => 'Als de URL van de Asset die geëxporteerd wordt een map is dan zal de mappenstructuur bijgevoegd worden. '
  },
  'does asset inherit URL from parent' => {
    'lastUpdated' => '1213624861',
    'message' => 'URL van ouder voorvoegen?'
  },
  'does asset inherit URL from parent description' => {
    'lastUpdated' => '1213624928',
    'message' => 'Moet dit Asset het URL van het bovenliggende object voor het URL voegen?'
  },
  'done' => {
    'lastUpdated' => '1146831597',
    'message' => 'Gereed'
  },
  'duplicate' => {
    'lastUpdated' => '1148988976',
    'message' => 'Dupliceer'
  },
  'duplicateField' => {
    'lastUpdated' => '1146831626',
    'message' => 'Foutmelding: Veldnaam &quot;%field%&quot; bestaat al.'
  },
  'edit' => {
    'lastUpdated' => '1146831634',
    'message' => 'Wijzig'
  },
  'edit branch' => {
    'lastUpdated' => '1146831657',
    'message' => 'Wijzig tak'
  },
  'edit branch help' => {
    'lastUpdated' => '1166204082',
    'message' => 'Laat de "Wijzig tak" functies zien om wijzigingen aan deze en onderliggende assets door te voeren. '
  },
  'edit branch url help' => {
    'lastUpdated' => '1207915565',
    'message' => '<p>De opgebouwde url bestaat uit twee gedeeltes. Voor het eerste gedeelte zijn er drie opties:</p><p>Bovenliggende url<br />&nbsp;&nbsp;&nbsp;&nbsp; begin de url met de url van de bovenliggende asset</p><p>Gespecificeerde url<br />&nbsp;&nbsp;&nbsp; Vul een zelf gespecifeerde url in om de url van de asset mee te beginnen</p><p>Geen<br />&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; Indien u kiest voor &quot;none&quot; dan wordt de url alleen opgebouwd uit het tweede gedeelte. De url komt dan &nbsp;&nbsp;&nbsp; &nbsp; gelijk achter de domeinnaam.</p><p>&nbsp;</p><p>Er zijn ook drie opties voor het tweede gedeelte:</p><p>Menutitel<br />&nbsp;&nbsp;&nbsp; De url wordt gebaseerd op de menutitel.</p><p>Titel<br />&nbsp;&nbsp;&nbsp; De url wordt gebaseerd op de titel.</p><p>Huidige url<br />&nbsp;&nbsp;&nbsp;&nbsp; De url wordt gebaseerd op de huidige url.</p><p>Alle url\'s worden automatisch aangepast om leestekens die problemen kunnen geven in een url te vervangen. </p>'
  },
  'editing %s' => {
    'lastUpdated' => '1246976741',
    'message' => '%s bewerken'
  },
  'encrypt page' => {
    'lastUpdated' => '1146831681',
    'message' => 'Pagina encrypten?'
  },
  'encrypt page description' => {
    'lastUpdated' => '1146831711',
    'message' => 'Moet de pagina van deze Asset via een ssl-verbinding worden uitgevoerd?'
  },
  'encryptPage' => {
    'lastUpdated' => '1170685765',
    'message' => 'Een booleaanse variabele (waar/niet waar) die waar is als dit asset is ingesteld op "weergeven via SSL (beveiligde verbinding)".'
  },
  'errorEmptyField' => {
    'lastUpdated' => '1146831731',
    'message' => 'Foutmelding: Veldnaam moet worden ingevuld.'
  },
  'export' => {
    'lastUpdated' => '1219727682',
    'message' => 'Meer'
  },
  'export information' => {
    'lastUpdated' => '1146831765',
    'message' => '%d pagina&#39;s ge&euml;xporteerd in %d seconden. '
  },
  'exporting page' => {
    'lastUpdated' => '1146831791',
    'message' => 'Pagina %-s wordt ge&euml;xporteerd...'
  },
  'extra head tags' => {
    'lastUpdated' => '1146831812',
    'message' => 'Extra &lt;head&gt; elementen'
  },
  'extra head tags description' => {
    'lastUpdated' => '1166187578',
    'message' => 'Deze tags zullen toegevoegd worden aan de &lt;head&gt; sectie van elke pagina waar de Asset wordt weergegeven.'
  },
  'extraHeadTags' => {
    'lastUpdated' => '1170685843',
    'message' => 'Extra tags die worden toegevoegd aan de header van de pagina waarop het asset staat. Deze zullen standaard worden bijgevoegd, zodat je ze niet zelf hoeft toe te voegen. '
  },
  'extrasUploads form hoverHelp' => {
    'lastUpdated' => '1166188112',
    'message' => 'Welke actie wilt u ondernemen met betrekking tot de extras en de uploads directory? Een symlink is een  symbolische link naar de originele directory. Als u "Geen" selecteert dan betekent dit dat u alle extras en uploads mappen negeert, hierdoor kunnen referenties naar deze mappen niet meer werken tenzij u de geexporteerde site al van deze mapstructuur heeft voorzien.'
  },
  'extrasUploads form label' => {
    'lastUpdated' => '1166188127',
    'message' => 'Extras en uploads mappen'
  },
  'extrasUploads form option none' => {
    'lastUpdated' => '1166188136',
    'message' => 'Geen'
  },
  'extrasUploads form option symlink' => {
    'lastUpdated' => '1166188149',
    'message' => 'Symbolische link'
  },
  'extrasUploads symlinking' => {
    'lastUpdated' => '1166188171',
    'message' => 'Symbolische link naar extras en uploads mappen'
  },
  'groupIdEdit' => {
    'lastUpdated' => '1170685868',
    'message' => 'De ID van de groep die dit asset mag bewerken.'
  },
  'groupIdView' => {
    'lastUpdated' => '1170685883',
    'message' => 'De ID van de groep die dit asset mag bekijken. '
  },
  'import' => {
    'lastUpdated' => '1146831872',
    'message' => 'Importeer'
  },
  'indexing %s' => {
    'lastUpdated' => '1246976759',
    'message' => '%s indexeren'
  },
  'inherit parent permissions' => {
    'lastUpdated' => '1222875714',
    'message' => 'Overnemen permissies van ouder'
  },
  'is not a valid userId' => {
    'lastUpdated' => '1224075598',
    'message' => 'is geen geldig gebruikersId.'
  },
  'isHidden' => {
    'lastUpdated' => '1170685926',
    'message' => 'Een booleaanse variabele (waar/niet-waar) die waar is als dit asset is ingesteld op "niet weergeven in navigaties". '
  },
  'isPackage' => {
    'lastUpdated' => '1170685987',
    'message' => 'Een booleaanse variabele, die waar is als dit asset is ingesteld op "is Package". '
  },
  'isPrototype' => {
    'lastUpdated' => '1170686022',
    'message' => 'Een booleaanse variabele (waar/niet-waar), die waar is als dit Asset is ingesteld op "is Prototype".'
  },
  'keywords' => {
    'lastUpdated' => '1190028040',
    'message' => 'trefwoorden'
  },
  'keywords help' => {
    'lastUpdated' => '1263483844',
    'message' => 'Trefwoorden worden automatisch toegevoegd aan de metatag van dit asset en de WebGUI zoekindex. Verschillende trefwoorden dienen gescheiden te worden door komma\'s.'
  },
  'keywords template var' => {
    'lastUpdated' => '1242135846',
    'message' => 'Dit wordt een string met sleutelwoorden voor dit asset. Aparte sleutelwoorden worden samengevoegd met spaties, tenzij het sleutelwoord spaties bevat. In dit laatste geval zullen de sleutelwoorden gequoted worden.'
  },
  'last updated' => {
    'lastUpdated' => '1146831886',
    'message' => 'Laatst gewijzigd'
  },
  'lock' => {
    'lastUpdated' => '1146831899',
    'message' => 'Vergrendelen'
  },
  'lock help' => {
    'lastUpdated' => '1148990815',
    'message' => 'Door de asset te vergrendelen kan iemand die niet dezelfde versie tag gebruikt de asset niet wijzigen. De optie wordt alleen weergegeven als de asset nog niet vergrendeld is. '
  },
  'locked' => {
    'lastUpdated' => '1146831911',
    'message' => 'Vergrendeld'
  },
  'locked by' => {
    'lastUpdated' => '1234738521',
    'message' => 'Vergendelt door'
  },
  'make asset exportable' => {
    'lastUpdated' => '1201182758',
    'message' => 'Deze Asset exporteerbaar maken?'
  },
  'make asset exportable description' => {
    'lastUpdated' => '1216986687',
    'message' => 'Kan deze Asset ge&euml;xporteerd worden als statische HTML, wat verschilt van een pakket? Deze Asset en alle ouders ervan moeten exporteerbaar zijn, voordat deze Asset het ook kan zijn. Ook moet exporteren ingeschakeld zijn in het WebGUI configuratiebestand van deze site.'
  },
  'make package' => {
    'lastUpdated' => '1146831942',
    'message' => 'Als Pakket activeren?'
  },
  'make package description' => {
    'lastUpdated' => '1166188189',
    'message' => 'Sommige taken moeten vaak worden uitgevoerd. Bijvoorbeeld het aanmaken van een Asset, of meerdere Assets. Door van deze Asset een pakket te maken kan dit worden geautomatiseerd. '
  },
  'make prototype' => {
    'lastUpdated' => '1146832154',
    'message' => 'Als prototype activeren?'
  },
  'make prototype description' => {
    'lastUpdated' => '1207915661',
    'message' => '<p>Als u Assets standaard op een bepaalde manier wilt instellen dan zijn prototypes erg handig. Door een Asset als prototype te activeren verschijnt deze in het menu bij de beschikbare Assets. De asset onthoudt dan de instellingen, zoals de gekozen template. </p><p>Voor de naam van de Asset in de Assetslijst wordt de Titel gebruikt. Als de titel hetzelfde is als de originele naam, bijvoorbeeld Artikel, dan wordt de originele asset hierdoor vervangen. </p>'
  },
  'manage' => {
    'lastUpdated' => '1146832496',
    'message' => 'Beheer'
  },
  'manage help' => {
    'lastUpdated' => '1148990937',
    'message' => 'Ga naar de Asset Manager. Deze geeft, indien aanwezig, de onderliggende assets weer. '
  },
  'menu label' => {
    'lastUpdated' => '1213625006',
    'message' => 'Meer'
  },
  'menuTitle' => {
    'lastUpdated' => '1170686045',
    'message' => 'De titel van het Asset die wordt gebruikt in navigaties.'
  },
  'metadata edit property' => {
    'lastUpdated' => '1146832509',
    'message' => 'Metadata, wijzig'
  },
  'missing page query' => {
    'lastUpdated' => '1149234520',
    'message' => 'De pagina die u heeft opgevraagd bestaat niet. Wat wilt u doen?'
  },
  'moving %s' => {
    'lastUpdated' => '1246969290',
    'message' => '%s verplaatsen'
  },
  'moving %s aside' => {
    'lastUpdated' => '1246976780',
    'message' => '%s opzij zetten'
  },
  'moving %s back' => {
    'lastUpdated' => '1246969309',
    'message' => '%s terug verplaatsen'
  },
  'need a depth' => {
    'lastUpdated' => '1224075611',
    'message' => 'Er is een niveau nodig'
  },
  'need a userId parameter' => {
    'lastUpdated' => '1224075636',
    'message' => 'Er is een gebruikersId parameter nodig.'
  },
  'newWindow' => {
    'lastUpdated' => '1170686157',
    'message' => 'Een booleaanse variabele (waar/niet-waar) die waar is als het asset is ingesteld op "open in nieuw venster".'
  },
  'no results' => {
    'lastUpdated' => '1213625018',
    'message' => 'Geen resultaten gevonden!'
  },
  'none' => {
    'lastUpdated' => '1148996723',
    'message' => 'Geen'
  },
  'over max assets' => {
    'lastUpdated' => '1207915712',
    'message' => 'De Administrator heeft het aantal te plaatsen Assets gelimiteerd. Deze limiet is overschreden. Om toch Assets te kunnen toevoegen dienen oudere Assets te worden verwijderd.'
  },
  'ownerUserId' => {
    'lastUpdated' => '1207915759',
    'message' => 'De ID van de gebruiker die eigenaar is van deze asset.'
  },
  'package corrupt' => {
    'lastUpdated' => '1146832748',
    'message' => 'Het pakket wat u geprobeerd heeft te importeren is corrupt. Alle bestanden tot op het moment van de corruptie zijn geimporteerd. Als u deze ook wilt verwijderen dan kan dit middels het terugzetten van de version tag. '
  },
  'package extract error' => {
    'lastUpdated' => '1206951462',
    'message' => 'Niet in staat om het pakket uit te pakken! Het pakket zou corrupt kunnen zijn of er kan een server fout zijn opgetreden door dat het voorkomen wordt dat pakketten worden ge&iuml;mporteerd.'
  },
  'packages' => {
    'lastUpdated' => '1146832764',
    'message' => 'Pakketten'
  },
  'page indicator' => {
    'lastUpdated' => '1213625034',
    'message' => 'Pagina %s van %s'
  },
  'parent url' => {
    'lastUpdated' => '1148996736',
    'message' => 'Bovenliggende url'
  },
  'pasting %s' => {
    'lastUpdated' => '1246969325',
    'message' => '%s plakken'
  },
  'promote' => {
    'lastUpdated' => '1146832794',
    'message' => 'Bevorder'
  },
  'promote %s' => {
    'lastUpdated' => '1246976797',
    'message' => '%s bevorderen'
  },
  'promote help' => {
    'lastUpdated' => '1148996763',
    'message' => 'Verplaats deze asset &eacute;&eacute;n plaats naar boven.'
  },
  'properties' => {
    'lastUpdated' => '1146832811',
    'message' => 'Eigenschappen'
  },
  'prototype using title' => {
    'lastUpdated' => '1146832840',
    'message' => 'Content prototypes, Gebruik van'
  },
  'purge' => {
    'lastUpdated' => '1146833103',
    'message' => 'Verwijder'
  },
  'purge old asset revisions' => {
    'lastUpdated' => '1146833089',
    'message' => 'Verwijder oude revisies '
  },
  'purge old trash' => {
    'lastUpdated' => '1146833073',
    'message' => 'Verwijder prullenbak '
  },
  'purge revision after' => {
    'lastUpdated' => '1146833058',
    'message' => 'Verwijder revisies na '
  },
  'purge revision after help' => {
    'lastUpdated' => '1146833031',
    'message' => 'Hoe lang moeten oude revisies van een Asset bewaard blijven? Oude Asset revisies zijn niet zichtbaar meer voor gebruikers maar blijven bewaard om eventueel terug te kunnen zetten'
  },
  'purge revision prompt' => {
    'lastUpdated' => '1370018628',
    'message' => 'Weet u zeker dat u deze revisie wilt verwijderen? Dit kan NIET ongedaan worden gemaakt. '
  },
  'purge trash after' => {
    'lastUpdated' => '1146833150',
    'message' => 'Verwijder prullenbak na'
  },
  'purge trash after help' => {
    'lastUpdated' => '1227567959',
    'message' => 'Hoe lang moet een Asset in de prullenbak bewaard blijven? Let op: zodra een Asset verwijderd wordt, zullen ook alle revisies en onderliggende assets verwijderd worden. '
  },
  'rank' => {
    'lastUpdated' => '1146833262',
    'message' => 'Rang'
  },
  'restore' => {
    'lastUpdated' => '1146833271',
    'message' => 'Herstel'
  },
  'revised by' => {
    'lastUpdated' => '1146833301',
    'message' => 'Herzien door'
  },
  'revision date' => {
    'lastUpdated' => '1146833312',
    'message' => 'Revisie datum'
  },
  'revisions' => {
    'lastUpdated' => '1146833321',
    'message' => 'Revisies'
  },
  'revisions help' => {
    'lastUpdated' => '1148996782',
    'message' => 'Bekijk de lijst met alle revisies van de asset'
  },
  'rootUrl default not present' => {
    'lastUpdated' => '1166188331',
    'message' => 'Geen symbolische link naar de standaard Asset; Deze wordt niet toegevoegd in de geexporteerde subtree.'
  },
  'rootUrl form hoverHelp' => {
    'lastUpdated' => '1166188780',
    'message' => 'Welke actie wilt u ondernemen met betrekking tot queries naar de root URL? "Symlink standaard" betekent dat u een symbolische link aanmaakt van het root URL indexbestand naar het indexbestand van de standaard Asset. "Geen" betekent niks doen wat er meestal voor zorgt dat de queries naar de root URL worden geweigerd in de geexporteerde site.'
  },
  'rootUrl form label' => {
    'lastUpdated' => '1166188625',
    'message' => 'Root URL'
  },
  'rootUrl form option none' => {
    'lastUpdated' => '1166188788',
    'message' => 'Geen'
  },
  'rootUrl form option symlinkDefault' => {
    'lastUpdated' => '1166188797',
    'message' => 'Symlink standaard'
  },
  'rootUrl symlinking default' => {
    'lastUpdated' => '1166188816',
    'message' => 'Symbolische link naar extras en uploads mappen.'
  },
  'save and commit' => {
    'lastUpdated' => '1155829051',
    'message' => 'opslaan en toepassen'
  },
  'search' => {
    'lastUpdated' => '1213625041',
    'message' => 'Zoeken'
  },
  'select all' => {
    'lastUpdated' => '1146833333',
    'message' => 'Alles selecteren'
  },
  'size' => {
    'lastUpdated' => '1146833342',
    'message' => 'Grootte'
  },
  'skipping %s' => {
    'lastUpdated' => '1246969342',
    'message' => '%s overslaan'
  },
  'specified base' => {
    'lastUpdated' => '1148996794',
    'message' => 'Gespecificeerde pagina'
  },
  'status' => {
    'lastUpdated' => '1170686328',
    'message' => 'De huidige staat van een asset volgens het versiebeheer. Deze staat wordt aangegeven met de Engelse termen "approved" (goedgekeurd), "pending" (in de wachtrij) en "committed" (verwerkt).'
  },
  'swap first' => {
    'lastUpdated' => '1248099838',
    'message' => 'Verruil eerste'
  },
  'swap second' => {
    'lastUpdated' => '1248099848',
    'message' => 'Verruil tweede'
  },
  'synopsis' => {
    'lastUpdated' => '1170686343',
    'message' => 'Een korte samenvatting van de inhoud van het asset.'
  },
  'tag name' => {
    'lastUpdated' => '1148996812',
    'message' => 'Tag naam'
  },
  'this asset only' => {
    'lastUpdated' => '1190028028',
    'message' => 'Alleen dit object (asset)'
  },
  'title' => {
    'lastUpdated' => '1170686354',
    'message' => 'De titel van het asset.'
  },
  'topicName' => {
    'lastUpdated' => '1146833355',
    'message' => 'Assets'
  },
  'type' => {
    'lastUpdated' => '1146833363',
    'message' => 'Type'
  },
  'unlocked' => {
    'lastUpdated' => '1234738549',
    'message' => 'vrijgegeven'
  },
  'update' => {
    'lastUpdated' => '1213625050',
    'message' => 'Vernieuwen'
  },
  'url' => {
    'lastUpdated' => '1170686364',
    'message' => 'De URL van het asset.'
  },
  'usePackedHeadTags description' => {
    'lastUpdated' => '1242135883',
    'message' => 'Gebruik de ingepakte versie van de headsectie tags voor snellere downloads'
  },
  'usePackedHeadTags label' => {
    'lastUpdated' => '1242135909',
    'message' => 'Gebruik ingepakte headsectie tags'
  },
  'view' => {
    'lastUpdated' => '1146833376',
    'message' => 'Bekijk'
  },
  'view help' => {
    'lastUpdated' => '1148996943',
    'message' => 'De meeste assets worden gebruikt om andere assets te kunnen bevattten zoals een pagina of een map. Met deze optie kan de asset individueel worden bekeken. '
  },
  'with children' => {
    'lastUpdated' => '1190028016',
    'message' => 'Met kinderen'
  },
  'with descendants' => {
    'lastUpdated' => '1190028008',
    'message' => 'Met nakomelingen'
  },
  'with selected' => {
    'lastUpdated' => '1213625069',
    'message' => 'Met selectie:'
  }
}
;

1;
